##  Maintenance Mode
When applying significant changes to your workspace, you can temporarily enable maintenance mode to prevent non-admin users from accessing the workspace. To minimize disruption to user workflows, consider conducting maintenance outside of regular business hours.
  * Non-admin users can not access the workspace during maintenance mode. A corresponding message (which you can customize) is displayed on the sign-in page. For those non-admin users who are currently signed in, a maintenance mode banner is displayed at the bottom of the screen. If a user signs out during maintenance mode, they will be unable to access the workspace until maintenance mode is disabled.
  * Admin users can still access the workspace during maintenance mode. A corresponding banner is displayed at the bottom of the screen.


To enable maintenance mode for a workspace, follow these steps:
  1. Navigate to the Settings section of the administration area.
  2. In the Maintenance Mode section, turn on the Enable Maintenance mode toggle.
  3. Optional: Customize the maintenance mode message that will be displayed to non-admin users on the sign-in page. You can preview how the message will appear while editing it.
You can include custom text and HTML links in your message. Any other HTML elements will be removed.
![Enabling Maintenance Mode for a Workspace](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274f32987a441014b0cf929e93e3fdb3_LowRes.png)
Enabling Maintenance Mode for a Workspace
  4. Click Save.


Once you’ve finished adjusting the necessary workspace settings, you can disable maintenance mode. To do that, turn off the Enable Maintenance mode toggle, then click Save.
